@@ -40,20 +40,11 @@
 #include "print.h"
 #include "i18n.h"
 #include "gtkutils.h"
+#include "errors.h"
 
-
-/*
- * not all systems have defined __compar_fn_t, original definition
- *  from glibc stdlib.h follows
- */
 /* Shorthand for type of comparison functions.  */
-#ifndef __COMPAR_FN_T
-# define __COMPAR_FN_T
-typedef int (*__compar_fn_t) __PMT ((__const __ptr_t, __const __ptr_t));
-
-# ifdef	__USE_GNU
-typedef __compar_fn_t comparison_fn_t;
-# endif
+#ifndef __GLIBC__
+#define __compar_fn_t int (*) (const void *, const void *)
 #endif
 
 typedef struct _PList PList;
@@ -89,6 +80,7 @@ struct _PrintData
   FaxPage *current_page;
   gint first_page, last_page;
   PDlgWidgets widgets;
+  DialogWindow *print_dialog;
   GtkWidget *parent_window;
 };
 
@@ -98,10 +90,147 @@ struct _OutputData
   FaxFile *document;
   gchar *out_file_name;
   gint from_page, to_page;
-  GtkWidget *print_dlg, *err_dlg, *parent_window;
+  DialogWindow *print_dialog, *err_dialog;
+  GtkWidget *parent_window;
 };
 
 #define MAX_PLIST 8
+static gchar *lpc_command = NULL;
+static gchar *lpstat_command = NULL;
+
+/* Do various tests to determine how to get the list of printers.
+   There are so many veriants of the lpr system... */
+static gchar *
+where_is (gchar *command)
+{
+  gchar **cur_dir, *path, *test_cmd, *result;
+  gchar *test_dirs[] =
+    {
+      "/usr/sbin",
+      "/usr/bin",
+      "/sbin",
+      "/bin",
+      NULL
+    };
+
+  result = NULL;
+  cur_dir = test_dirs;
+
+  while (!result && *cur_dir)
+    {
+      path = *cur_dir;
+      test_cmd = g_strdup_printf ("%s/%s", path, command);
+
+      if (access (test_cmd, X_OK))
+	{
+	  g_free (test_cmd);
+	  cur_dir++;
+	}
+      else
+	result = test_cmd;
+    }
+
+  return result;
+}
+
+static gchar *
+cmd_result (gchar *cmd)
+{
+  FILE *pfile;
+  gchar *result;
+
+  result = NULL;
+  pfile = popen (cmd, "r");
+
+  if (pfile)
+    {
+      result = g_malloc (129);
+      fgets(result, 129, pfile);
+      pclose (pfile);
+    }
+
+  return result;
+}
+
+static gboolean
+test_lpc (gchar *lpc)
+{
+  gboolean ret_code;
+  gchar *command, *result;
+
+  ret_code = FALSE;
+  command = g_strdup_printf ("%s status < /dev/null", lpc);
+  result = cmd_result (command);
+
+  /* FreeBSD lpr needs to have a printer specified or "all", while
+     other versions don't */
+  if (!strncmp (result, "Usage:", 6))
+    {
+      g_free (result);
+      g_free (command);
+
+      command = g_strdup_printf ("%s status all < /dev/null", lpc);
+      result = cmd_result (command);
+      
+      if (strncmp (result, "unknown", 7))
+	{
+	  lpc_command = command;
+	  ret_code = TRUE;
+	}
+      else
+	g_free (command);
+
+      g_free (result);
+    }
+  else
+    {
+      g_free (result);
+      lpc_command = command;
+      ret_code = TRUE;
+    }	    
+  
+  return ret_code;
+}
+
+static gboolean
+test_lpstat (gchar *lpstat)
+{
+  gboolean ret_code;
+/*   gchar *command, *result; */
+
+  /* I have yet to test multiple versions of lpstat... */
+  ret_code = TRUE;
+  lpstat_command = g_strdup_printf ("%s -d -p < /dev/null", lpstat);
+
+  return ret_code;
+}
+
+static gboolean
+ensure_commands ()
+{
+  gboolean ret_code;
+  gchar *lpc, *lpstat;
+  
+  if (lpc_command || lpstat_command)
+    ret_code = TRUE;
+  else
+    {
+      lpc = where_is ("lpc");
+      lpstat = where_is ("lpstat");
+         
+      if (lpc)
+	ret_code = test_lpc (lpc);
+      else if (lpstat)
+	ret_code = test_lpstat (lpstat);
+      else
+	ret_code = FALSE;
+
+      g_free (lpc);
+      g_free (lpstat);
+    }
+
+  return ret_code;
+}
 
 static int
 compare_printers (PList *p1, PList *p2)
@@ -137,47 +266,46 @@ make_default_pr (PList *plist, int nbr_pr, char *defname)
 static PList*
 get_printers (void)
 {
-  int plist_count;
-  char defname[17];
+  gint plist_count;
+  gchar defname[17], name[17];
+  gchar line[129];
   PList *plist;
-#if defined(LPC_COMMAND) || defined(LPSTAT_COMMAND)
   FILE *pfile;
-  char line[129];
-#endif	
 	
   defname[0] = '\0';
   
   plist = g_malloc0 (sizeof (PList) * MAX_PLIST);
   plist_count = 0;
-  
-#ifdef LPC_COMMAND
-  pfile = popen (LPC_COMMAND " status < /dev/null", "r");
-  if (pfile)
-    {
-      while (fgets(line, sizeof (line), pfile) != NULL
-	     && plist_count < MAX_PLIST)
-	if (strchr(line, ':') != NULL
-	    && line[0] != ' '
-	    && line[0] != '\t'
-	    && strncmp(line, "Press RETURN to continue", 24))
-	  {
-	    *strchr(line, ':') = '\0';
-	    strcpy(plist[plist_count].name, line);
-	    if (plist_count == 0)
-	      strcpy(defname, line);
-	    plist[plist_count].active = TRUE;
-	    plist[plist_count].is_default = FALSE;
-	    plist_count++;
-	  }
+
+  if (lpc_command)
+    {  
+      pfile = popen (lpc_command, "r");
+
+      if (pfile)
+	{
+	  while (fgets(line, sizeof (line), pfile)
+		 && plist_count < MAX_PLIST)
+	    if (strchr(line, ':')
+		&& line[0] != ' '
+		&& line[0] != '\t'
+		&& strncmp(line, "Press RETURN to continue", 24))
+	      {
+		*strchr(line, ':') = '\0';
+		strcpy(plist[plist_count].name, line);
+		if (plist_count == 0)
+		  strcpy(defname, line);
+		plist[plist_count].active = TRUE;
+		plist[plist_count].is_default = FALSE;
+		plist_count++;
+	      }
       
-      pclose(pfile);
+	  pclose(pfile);
+	}
     }
-#endif /* LPC_COMMAND */
-	
-#ifdef LPSTAT_COMMAND
-  if (!plist_count)
+
+  if (!plist_count && lpstat_command)
     {
-      pfile = popen (LPSTAT_COMMAND " -d -p", "r");
+      pfile = popen (lpstat_command, "r");
       if (pfile)
 	{
 	  while (fgets (line, sizeof (line), pfile) != NULL
@@ -198,7 +326,6 @@ get_printers (void)
 	  pclose(pfile);
 	}
     }
-#endif /* LPSTAT_COMMAND */
 	
   if (plist_count)
     {
@@ -257,8 +384,8 @@ make_printer_menu (PrintData *print_data)
 	  cur_printer++;
 	}
 
-      gtk_object_set_data_full (GTK_OBJECT (menu), "printer_list",
-				plist, g_free);
+      gtk_signal_connect (GTK_OBJECT (menu), "destroy",
+			  free_data_on_destroy_cb, plist);
     }
   else
     menu = NULL;
@@ -502,8 +629,6 @@ create_temp_print_file (gchar **outfile_name)
   
   template = g_strdup ("/tmp/gfo-XXXXXX");
 
-#warning Ignore the warning about mktemp at link time,
-#warning it is used securely here...
   while (!file_stream && counter < 64)
     {
       file_name = mktemp (template);
@@ -573,17 +698,17 @@ print_image (FILE *print_file, FaxPage *fax_image,
       if (!aborted)
 	{
 	  cur_char = *(fax_image->image + counter);
-	  fprintf(print_file, "%.2x", (unsigned char) ~cur_char);
+	  fprintf (print_file, "%.2x", (unsigned char) ~cur_char);
 		
 	  if ((counter + 1) % 40 == 0)
-	    fprintf(print_file, "\n");
+	    fprintf (print_file, "\n");
 	}
       else
 	new_progress = 0;
     }
 
   if (!aborted && ((counter + 1) % 40 != 0))
-    fprintf(print_file, "\n");
+    fprintf (print_file, "\n");
 
   return new_progress;
 }
@@ -621,20 +746,20 @@ output_document (OutputData *output_data)
 			      VERSION,
 			      output_data->document->file_name);
 
-  fprintf(output_data->output_stream,
-	  "%%!PS-Adobe-3.0\n"
-	  "%%%%Creator: %s\n"
-	  "%%%%Title: %s\n"
-	  "%%%%CreationDate: %s"
-	  "%%%%DocumentData: Clean7Bit\n"
-	  "%%%%Origin: 0 0\n"
-	  "%%%%BoundingBox: 0 0 612 792\n"
-	  "%%%%LanguageLevel: 1\n"
-	  "%%%%Pages: (atend)\n"
-	  "%%%%EndComments\n"
-	  "%%%%BeginSetup\n"
-	  "%%%%EndSetup\n",
-	  ps_creator, ps_title, time_string);
+  fprintf (output_data->output_stream,
+	   "%%!PS-Adobe-3.0\n"
+	   "%%%%Creator: %s\n"
+	   "%%%%Title: %s\n"
+	   "%%%%CreationDate: %s"
+	   "%%%%DocumentData: Clean7Bit\n"
+	   "%%%%Origin: 0 0\n"
+	   "%%%%BoundingBox: 0 0 612 792\n"
+	   "%%%%LanguageLevel: 1\n"
+	   "%%%%Pages: (atend)\n"
+	   "%%%%EndComments\n"
+	   "%%%%BeginSetup\n"
+	   "%%%%EndSetup\n",
+	   ps_creator, ps_title, time_string);
   
   g_free (ps_title);
   g_free (ps_creator);
@@ -653,33 +778,33 @@ output_document (OutputData *output_data)
       cur_page = ti_seek_fax_page (output_data->document,
 				   cur_page_nbr - 1);
 
-      fprintf(output_data->output_stream,
-	      "%%%%Page: %d %d\n",
-	      cur_page_nbr,
-	      cur_page_nbr);
-      fprintf(output_data->output_stream,
-	      "gsave\n"
-	      "100 dict begin\n"
-	      "%f %f scale\n",
-	      ((float) cur_page->width * 72.0
-	       / (float) output_data->document->x_res),
-	      ((float) cur_page->height
-	       * 72.0
-	       / (float) output_data->document->y_res));
-      fprintf(output_data->output_stream,
-	      "%%ImageData: %d %d 1 1 0 1 2 \"image\"\n",
-	      cur_page->width, cur_page->height);
-      fprintf(output_data->output_stream,
-	      "/scanLine %d string def\n",
-	      (int) (cur_page->width / 8));
-      fprintf(output_data->output_stream,
-	      "%d %d 1\n", cur_page->width, cur_page->height);
-      fprintf(output_data->output_stream,
-	      "[%d 0 0 -%d 0 %d]\n", cur_page->width,
-	      cur_page->height, cur_page->height);
-      fprintf(output_data->output_stream,
-	      "{currentfile scanLine readhexstring pop} bind\n"
-	      "image\n");
+      fprintf (output_data->output_stream,
+	       "%%%%Page: %d %d\n",
+	       cur_page_nbr,
+	       cur_page_nbr);
+      fprintf (output_data->output_stream,
+	       "gsave\n"
+	       "100 dict begin\n"
+	       "%f %f scale\n",
+	       ((float) cur_page->width * 72.0
+		/ (float) output_data->document->x_res),
+	       ((float) cur_page->height
+		* 72.0
+		/ (float) output_data->document->y_res));
+      fprintf (output_data->output_stream,
+	       "%%ImageData: %d %d 1 1 0 1 2 \"image\"\n",
+	       cur_page->width, cur_page->height);
+      fprintf (output_data->output_stream,
+	       "/scanLine %d string def\n",
+	       (int) (cur_page->width / 8));
+      fprintf (output_data->output_stream,
+	       "%d %d 1\n", cur_page->width, cur_page->height);
+      fprintf (output_data->output_stream,
+	       "[%d 0 0 -%d 0 %d]\n", cur_page->width,
+	       cur_page->height, cur_page->height);
+      fprintf (output_data->output_stream,
+	       "{currentfile scanLine readhexstring pop} bind\n"
+	       "image\n");
       
       ti_load_fax_page (output_data->document, cur_page);
       cur_byte = print_image (output_data->output_stream,
@@ -690,10 +815,10 @@ output_document (OutputData *output_data)
 	success = FALSE;
       else
 	{
-	  fprintf(output_data->output_stream,
-		  "end\n"
-		  "grestore\n"
-		  "showpage\n");
+	  fprintf (output_data->output_stream,
+		   "end\n"
+		   "grestore\n"
+		   "showpage\n");
 
 	  cur_page_nbr++;
 	}
@@ -717,84 +842,84 @@ output_document (OutputData *output_data)
   return success;
 }
 
-static gint
-print_to_file_anyway_cb (GtkWidget *yes_button, OutputData
-			 *output_data)
+static void
+print_to_file_anyway_cb (GtkWidget *yes_button,
+			 OutputData *output_data)
 {
   gboolean success;
-  
-  gtk_widget_destroy (output_data->err_dlg);
-  
-  while (gtk_events_pending ())
-    gtk_main_iteration ();
+  DialogWindow *print_dialog;
   
   output_data->output_stream = fopen (output_data->out_file_name, "w+");
   success = output_document (output_data);
-  
-  if (success)
-    gtk_widget_destroy (output_data->print_dlg);
-  else
-    unlink (output_data->out_file_name);
-
   fclose (output_data->output_stream);
-  g_free (output_data->out_file_name);
-  g_free (output_data);
   
-  return FALSE;
-}
+  print_dialog = output_data->print_dialog;
 
-static gint
-no_overwrite_cb (GtkWidget *no_button, OutputData *output_data)
-{
-  gtk_widget_destroy (output_data->err_dlg);
-  g_free (output_data->out_file_name);
-  g_free (output_data);
-
-  return FALSE;
+  if (success)
+    {
+      dialog_window_destroy (output_data->err_dialog);
+      dialog_window_destroy (print_dialog);
+    }
+  else
+    {
+      unlink (output_data->out_file_name);
+      dialog_window_destroy (output_data->err_dialog);
+    }
 }
 
 static void
-file_exists_dlg (OutputData *output_data, GtkWidget *print_dlg)
+file_exists_dialog_destroy_cb (GtkWidget *window, OutputData *output_data)
 {
-  GtkWidget *err_win, *vbox, *hbox, *msg_lbl, *yes_but, *no_but;
+  g_free (output_data->out_file_name);
+  g_free (output_data);
+}
+
+static void
+file_exists_dialog (OutputData *output_data, DialogWindow *print_dialog)
+{
+  DialogWindow *err_dialog;
+  GtkWidget *button_box, *msg_lbl, *yes_but, *no_but;
   gchar *message;
   
   message = g_strdup_printf (_("%s already exists.\n"
 			       "Do you want to overwrite it?"),
 			     output_data->out_file_name);
 
-  err_win = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title (GTK_WINDOW (err_win), _("Please answer..."));
-  gtk_container_set_border_width (GTK_CONTAINER (err_win), 10);
-  
-  vbox = gtk_vbox_new (FALSE, 1);
-  gtk_container_add (GTK_CONTAINER (err_win), vbox);
-	
+  err_dialog = dialog_window_new (_("Please answer..."));
+  dialog_window_add_destroy_callback (err_dialog,
+				      GTK_SIGNAL_FUNC (file_exists_dialog_destroy_cb),
+				      output_data);
+
   msg_lbl = gtk_label_new (message);
   g_free (message);
-  gtk_box_pack_start (GTK_BOX (vbox), msg_lbl, TRUE, FALSE, 3);
   gtk_label_set_justify (GTK_LABEL (msg_lbl), GTK_JUSTIFY_LEFT);
+  dialog_window_set_content_with_frame (err_dialog, msg_lbl);
   
-  hbox = gtk_hbox_new (FALSE, 3);
-  gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, FALSE, 0);
-  
-  output_data->err_dlg = err_win;
-  output_data->print_dlg = print_dlg;
+  button_box = dialog_window_bbox ();
+  dialog_window_set_button_box (err_dialog, GTK_HBUTTON_BOX (button_box));
+  dialog_window_set_escapable (err_dialog);
 
   yes_but = gtk_button_new_with_label (_("Yes, please do"));
   gtk_signal_connect (GTK_OBJECT (yes_but), "clicked",
 		      GTK_SIGNAL_FUNC (print_to_file_anyway_cb),
 		      output_data);
-  gtk_box_pack_start (GTK_BOX (hbox), yes_but, TRUE, FALSE, 2);
-  
+  gtk_box_pack_start (GTK_BOX (button_box), yes_but,
+		      FALSE, FALSE, 5);
+  GTK_WIDGET_SET_FLAGS (yes_but, GTK_CAN_DEFAULT);
+
   no_but = gtk_button_new_with_label (_("No thanks"));
   gtk_signal_connect (GTK_OBJECT (no_but), "clicked",
-		      GTK_SIGNAL_FUNC (no_overwrite_cb),
-		      output_data);
-  gtk_box_pack_start (GTK_BOX (hbox), no_but, TRUE, FALSE, 2);
+		      GTK_SIGNAL_FUNC (dialog_window_destroy_from_signal),
+		      err_dialog);
+  gtk_box_pack_start (GTK_BOX (button_box), no_but,
+		      FALSE, FALSE, 5);
+  GTK_WIDGET_SET_FLAGS(no_but, GTK_CAN_DEFAULT);
+  gtk_widget_grab_default (no_but);
 
-  transient_window_show (GTK_WINDOW (err_win),
-			 GTK_WINDOW (print_dlg));
+  output_data->err_dialog = err_dialog;
+  output_data->print_dialog = print_dialog;
+
+  dialog_window_show (err_dialog, dialog_window_get_gtkwin (print_dialog));
 }
 
 static gint
@@ -835,7 +960,6 @@ launch_print_job_cb (GtkWidget *widget,
       output_data->from_page = output_data->to_page =
 	print_data->current_page->nbr + 1;
 
-
   if (direction == PRINT_TO_PRINTER)
     {
       print_command = gtk_entry_get_text
@@ -855,7 +979,7 @@ launch_print_job_cb (GtkWidget *widget,
 	  system (command);
 	  g_free (command);
 
-	  gtk_widget_destroy (widget->parent->parent);
+	  dialog_window_destroy (print_data->print_dialog);
 	}
 
       unlink (output_data->out_file_name);
@@ -881,84 +1005,101 @@ launch_print_job_cb (GtkWidget *widget,
 	  g_free (output_data->out_file_name);
 	  g_free (output_data);
 
-	  gtk_widget_destroy (widget->parent->parent);
+	  dialog_window_destroy (print_data->print_dialog);
 	}
       else
-	file_exists_dlg (output_data, widget->parent->parent);
+	file_exists_dialog (output_data, print_data->print_dialog);
     }
 
-
   return FALSE;
 }
 
-static gint
-cancel_print_cb (GtkWidget *widget, gpointer null)
+static void
+print_dialog_bbox (PrintData *print_data)
 {
-  gtk_widget_destroy (widget->parent->parent);
+  GtkWidget *button_box, *print_but, *cancel_but;
 
-  return FALSE;
+  button_box = dialog_window_bbox ();
+  dialog_window_set_button_box (print_data->print_dialog,
+				GTK_HBUTTON_BOX (button_box));
+  dialog_window_set_escapable (print_data->print_dialog);
+
+  print_but = gtk_button_new_with_label (_("Print"));
+  GTK_WIDGET_SET_FLAGS(print_but, GTK_CAN_DEFAULT);
+  gtk_box_pack_start (GTK_BOX (button_box), print_but, FALSE, FALSE, 0);
+  gtk_widget_grab_default (print_but);
+  gtk_signal_connect (GTK_OBJECT (print_but), "clicked",
+		      GTK_SIGNAL_FUNC (launch_print_job_cb),
+		      print_data);
+
+  cancel_but = gtk_button_new_with_label (_("Cancel"));
+  GTK_WIDGET_SET_FLAGS(cancel_but, GTK_CAN_DEFAULT);
+  gtk_box_pack_start (GTK_BOX (button_box), cancel_but, FALSE, FALSE, 0);
+  gtk_signal_connect (GTK_OBJECT (cancel_but), "clicked",
+		      GTK_SIGNAL_FUNC (dialog_window_destroy_from_signal),
+		      print_data->print_dialog);
+
+  gtk_widget_show (button_box);
 }
 
-static GtkWidget*
+static DialogWindow *
 print_dialog (ViewerData *viewer_data)
 {
-  GtkWidget *print_dlg, *table,
-    *output_frame, *page_frame,
-    *print_but, *cancel_but;
+  DialogWindow *print_dialog;
+  GtkWidget *table, *output_frame, *page_frame;
   PrintData *print_data;
 
+  print_dialog = dialog_window_new (_("Print..."));
+
   print_data = g_malloc (sizeof (PrintData));
   print_data->document = viewer_data->fax_file;
   print_data->current_page = viewer_data->current_page;
   print_data->parent_window = viewer_data->viewer_window;
-
-  print_dlg = gtk_window_new (GTK_WINDOW_DIALOG);
-  gtk_window_set_title (GTK_WINDOW (print_dlg), _("Print..."));
-  gtk_container_set_border_width (GTK_CONTAINER (print_dlg), 3);
+  print_data->print_dialog = print_dialog;
 
   table = gtk_table_new (3, 2, FALSE);
   gtk_table_set_row_spacings (GTK_TABLE (table), 5);
   gtk_table_set_col_spacings (GTK_TABLE (table), 5);
-  gtk_container_add (GTK_CONTAINER (print_dlg), table);
-
   output_frame = make_output_frame (print_data);
+  page_frame = make_page_frame (print_data);
+
   gtk_table_attach_defaults (GTK_TABLE (table), output_frame,
 			     0, 2, 0, 1); 
-
-  page_frame = make_page_frame (print_data);
   gtk_table_attach_defaults (GTK_TABLE (table), page_frame,
 			     0, 2, 1, 2); 
 
-  print_but = gtk_button_new_with_label (_("Print"));
-  gtk_signal_connect (GTK_OBJECT (print_but), "clicked",
-		      GTK_SIGNAL_FUNC (launch_print_job_cb),
-		      print_data);
-  gtk_table_attach_defaults (GTK_TABLE (table),
-			     print_but,
-			     0, 1, 2, 3); 
-  
-  cancel_but = gtk_button_new_with_label (_("Cancel"));
-  gtk_signal_connect (GTK_OBJECT (cancel_but), "clicked",
-		      GTK_SIGNAL_FUNC (cancel_print_cb),
-		      NULL);
-  gtk_table_attach_defaults (GTK_TABLE (table), cancel_but,
-			     1, 2, 2, 3); 
+  print_dialog_bbox (print_data);
 
-  gtk_object_set_data_full (GTK_OBJECT (print_dlg),
-			    "print_data", print_data, g_free);
+  dialog_window_set_content (print_dialog, table);
+  dialog_window_add_destroy_callback (print_dialog,
+				      GTK_SIGNAL_FUNC (free_data_on_destroy_cb),
+				      print_data);
 
-  return print_dlg;
+  return print_dialog;
 }
 
 void
 print_cb (GtkWidget *widget, ViewerData *viewer_data)
 {
-  if (viewer_data->fax_file)
+  DialogWindow *print_dlg;
+
+  if (ensure_commands ())
     {
-      viewer_data->print_dialog =
-	print_dialog (viewer_data);
-      
-      transient_window_show (GTK_WINDOW (viewer_data->print_dialog),
-			     GTK_WINDOW (viewer_data->viewer_window));
+      print_dlg = print_dialog (viewer_data);
+      dialog_window_show (print_dlg, GTK_WINDOW (viewer_data->viewer_window));
+    }
+  else
+    {
+      display_failure (viewer_data->viewer_window,
+		       _("This is weird..."),
+		       _("I was not able to determine how to work\n"
+			 "with your printing system appropriately.\n\n"
+			 "Please have your administrator verify if\n"
+			 "a descent printing system is installed.\n"
+			 "If this is so, there must be a bug in\n"
+			 "ghfaxviewer.\n"
+			 "In this case, please fill a bug report\n"
+			 "and send it to halifax-bugs@gnu.org."),
+		       _("I promise!"));
     }
 }
